/* individual-retrieval.c generated by valac 0.24.0.16-c045, the Vala compiler
 * generated from individual-retrieval.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <eds-test.h>
#include <folks/folks.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <folks/folks-eds.h>
#include <gio/gio.h>


#define TYPE_INDIVIDUAL_RETRIEVAL_TESTS (individual_retrieval_tests_get_type ())
#define INDIVIDUAL_RETRIEVAL_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_INDIVIDUAL_RETRIEVAL_TESTS, IndividualRetrievalTests))
#define INDIVIDUAL_RETRIEVAL_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_INDIVIDUAL_RETRIEVAL_TESTS, IndividualRetrievalTestsClass))
#define IS_INDIVIDUAL_RETRIEVAL_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_INDIVIDUAL_RETRIEVAL_TESTS))
#define IS_INDIVIDUAL_RETRIEVAL_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_INDIVIDUAL_RETRIEVAL_TESTS))
#define INDIVIDUAL_RETRIEVAL_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_INDIVIDUAL_RETRIEVAL_TESTS, IndividualRetrievalTestsClass))

typedef struct _IndividualRetrievalTests IndividualRetrievalTests;
typedef struct _IndividualRetrievalTestsClass IndividualRetrievalTestsClass;
typedef struct _IndividualRetrievalTestsPrivate IndividualRetrievalTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _IndividualRetrievalTestsTestSingletonIndividualsAsyncData IndividualRetrievalTestsTestSingletonIndividualsAsyncData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _IndividualRetrievalTests {
	EdsTestTestCase parent_instance;
	IndividualRetrievalTestsPrivate * priv;
};

struct _IndividualRetrievalTestsClass {
	EdsTestTestCaseClass parent_class;
};

struct _IndividualRetrievalTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	GeeHashSet* _found_individuals;
};

struct _IndividualRetrievalTestsTestSingletonIndividualsAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	IndividualRetrievalTests* self;
	EdsTestBackend* _tmp0_;
	FolksBackendStore* store;
	FolksBackendStore* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	FolksIndividualAggregator* _tmp4_;
	GError* e;
	GError* _tmp5_;
	const gchar* _tmp6_;
	GError * _inner_error_;
};


static gpointer individual_retrieval_tests_parent_class = NULL;

GType individual_retrieval_tests_get_type (void) G_GNUC_CONST;
#define INDIVIDUAL_RETRIEVAL_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_INDIVIDUAL_RETRIEVAL_TESTS, IndividualRetrievalTestsPrivate))
enum  {
	INDIVIDUAL_RETRIEVAL_TESTS_DUMMY_PROPERTY
};
IndividualRetrievalTests* individual_retrieval_tests_new (void);
IndividualRetrievalTests* individual_retrieval_tests_construct (GType object_type);
void individual_retrieval_tests_test_singleton_individuals (IndividualRetrievalTests* self);
static void _individual_retrieval_tests_test_singleton_individuals_folks_test_case_test_method (gpointer self);
static GValue* _g_value_dup (GValue* self);
static void _vala_GValue_free (GValue* self);
static void _individual_retrieval_tests_test_singleton_individuals_async (IndividualRetrievalTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _individual_retrieval_tests_test_singleton_individuals_finish (IndividualRetrievalTests* self, GAsyncResult* _res_);
static void _individual_retrieval_tests_test_singleton_individuals_async_data_free (gpointer _data);
static gboolean _individual_retrieval_tests_test_singleton_individuals_async_co (IndividualRetrievalTestsTestSingletonIndividualsAsyncData* _data_);
static void _individual_retrieval_tests_test_singleton_individuals_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _individual_retrieval_tests_individuals_changed_cb (IndividualRetrievalTests* self, GeeMultiMap* changes);
static void __individual_retrieval_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void individual_retrieval_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _individual_retrieval_tests_test_singleton_individuals_folks_test_case_test_method (gpointer self) {
#line 35 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	individual_retrieval_tests_test_singleton_individuals ((IndividualRetrievalTests*) self);
#line 115 "individual-retrieval.c"
}


IndividualRetrievalTests* individual_retrieval_tests_construct (GType object_type) {
	IndividualRetrievalTests * self = NULL;
#line 33 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	self = (IndividualRetrievalTests*) eds_test_test_case_construct (object_type, "IndividualRetrieval");
#line 35 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "singleton individuals", _individual_retrieval_tests_test_singleton_individuals_folks_test_case_test_method, self);
#line 31 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	return self;
#line 127 "individual-retrieval.c"
}


IndividualRetrievalTests* individual_retrieval_tests_new (void) {
#line 31 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	return individual_retrieval_tests_construct (TYPE_INDIVIDUAL_RETRIEVAL_TESTS);
#line 134 "individual-retrieval.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 40 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 141 "individual-retrieval.c"
}


static void _vala_GValue_free (GValue* self) {
#line 40 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	g_value_unset (self);
#line 40 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	g_free (self);
#line 150 "individual-retrieval.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 48 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	return self ? _g_value_dup (self) : NULL;
#line 157 "individual-retrieval.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 54 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	return self ? g_object_ref (self) : NULL;
#line 164 "individual-retrieval.c"
}


void individual_retrieval_tests_test_singleton_individuals (IndividualRetrievalTests* self) {
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp0_ = NULL;
	GeeHashMap* c2 = NULL;
	GeeHashMap* _tmp1_ = NULL;
	GeeHashSet* _tmp2_ = NULL;
	GMainLoop* _tmp3_ = NULL;
	GValue* v = NULL;
	EdsTestBackend* _tmp4_ = NULL;
	GValue _tmp5_ = {0};
	GValue _tmp6_ = {0};
	GValue* _tmp7_ = NULL;
	GValue* _tmp8_ = NULL;
	GValue* _tmp9_ = NULL;
	GValue* _tmp10_ = NULL;
	GValue _tmp11_ = {0};
	GValue _tmp12_ = {0};
	GValue* _tmp13_ = NULL;
	GValue* _tmp14_ = NULL;
	const gchar* _tmp15_ = NULL;
	GValue* _tmp16_ = NULL;
	GValue* _tmp17_ = NULL;
	EdsTestBackend* _tmp18_ = NULL;
	GeeHashMap* _tmp19_ = NULL;
	GValue _tmp20_ = {0};
	GValue _tmp21_ = {0};
	GValue* _tmp22_ = NULL;
	GValue* _tmp23_ = NULL;
	GValue* _tmp24_ = NULL;
	GValue* _tmp25_ = NULL;
	GValue _tmp26_ = {0};
	GValue _tmp27_ = {0};
	GValue* _tmp28_ = NULL;
	GValue* _tmp29_ = NULL;
	const gchar* _tmp30_ = NULL;
	GValue* _tmp31_ = NULL;
	GValue* _tmp32_ = NULL;
	EdsTestBackend* _tmp33_ = NULL;
	GeeHashMap* _tmp34_ = NULL;
	GMainLoop* _tmp35_ = NULL;
	GeeHashSet* _tmp36_ = NULL;
	gint _tmp37_ = 0;
	gint _tmp38_ = 0;
#line 38 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	g_return_if_fail (self != NULL);
#line 40 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp0_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 40 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	c1 = _tmp0_;
#line 41 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 41 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	c2 = _tmp1_;
#line 42 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp2_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 42 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_g_object_unref0 (self->priv->_found_individuals);
#line 42 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	self->priv->_found_individuals = _tmp2_;
#line 43 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp3_ = g_main_loop_new (NULL, FALSE);
#line 43 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 43 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	self->priv->_main_loop = _tmp3_;
#line 46 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp4_ = ((EdsTestTestCase*) self)->eds_backend;
#line 46 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	eds_test_backend_reset (_tmp4_);
#line 48 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	g_value_init (&_tmp5_, G_TYPE_STRING);
#line 48 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp6_ = _tmp5_;
#line 48 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp7_ = __g_value_dup0 (&_tmp6_);
#line 48 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	__vala_GValue_free0 (v);
#line 48 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	v = _tmp7_;
#line 48 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	G_IS_VALUE (&_tmp6_) ? (g_value_unset (&_tmp6_), NULL) : NULL;
#line 49 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp8_ = v;
#line 49 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	g_value_set_string (_tmp8_, "bernie h. innocenti");
#line 50 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp9_ = v;
#line 50 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	v = NULL;
#line 50 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp10_ = _tmp9_;
#line 50 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, "full_name", _tmp10_);
#line 50 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	__vala_GValue_free0 (_tmp10_);
#line 51 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	g_value_init (&_tmp11_, G_TYPE_STRING);
#line 51 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp12_ = _tmp11_;
#line 51 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp13_ = __g_value_dup0 (&_tmp12_);
#line 51 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	__vala_GValue_free0 (v);
#line 51 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	v = _tmp13_;
#line 51 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	G_IS_VALUE (&_tmp12_) ? (g_value_unset (&_tmp12_), NULL) : NULL;
#line 52 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp14_ = v;
#line 52 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	g_value_set_string (_tmp14_, "bernie@example.org");
#line 53 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp15_ = EDSF_PERSONA_email_fields[0];
#line 53 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp16_ = v;
#line 53 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	v = NULL;
#line 53 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp17_ = _tmp16_;
#line 53 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, _tmp15_, _tmp17_);
#line 53 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	__vala_GValue_free0 (_tmp17_);
#line 54 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp18_ = ((EdsTestTestCase*) self)->eds_backend;
#line 54 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp19_ = _g_object_ref0 (c1);
#line 54 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	eds_test_backend_add_contact (_tmp18_, _tmp19_);
#line 56 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	g_value_init (&_tmp20_, G_TYPE_STRING);
#line 56 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp21_ = _tmp20_;
#line 56 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp22_ = __g_value_dup0 (&_tmp21_);
#line 56 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	__vala_GValue_free0 (v);
#line 56 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	v = _tmp22_;
#line 56 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	G_IS_VALUE (&_tmp21_) ? (g_value_unset (&_tmp21_), NULL) : NULL;
#line 57 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp23_ = v;
#line 57 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	g_value_set_string (_tmp23_, "richard m. stallman");
#line 58 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp24_ = v;
#line 58 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	v = NULL;
#line 58 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp25_ = _tmp24_;
#line 58 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c2, "full_name", _tmp25_);
#line 58 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	__vala_GValue_free0 (_tmp25_);
#line 59 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	g_value_init (&_tmp26_, G_TYPE_STRING);
#line 59 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp27_ = _tmp26_;
#line 59 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp28_ = __g_value_dup0 (&_tmp27_);
#line 59 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	__vala_GValue_free0 (v);
#line 59 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	v = _tmp28_;
#line 59 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	G_IS_VALUE (&_tmp27_) ? (g_value_unset (&_tmp27_), NULL) : NULL;
#line 60 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp29_ = v;
#line 60 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	g_value_set_string (_tmp29_, "rms@example.org");
#line 61 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp30_ = EDSF_PERSONA_email_fields[0];
#line 61 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp31_ = v;
#line 61 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	v = NULL;
#line 61 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp32_ = _tmp31_;
#line 61 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c2, _tmp30_, _tmp32_);
#line 61 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	__vala_GValue_free0 (_tmp32_);
#line 62 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp33_ = ((EdsTestTestCase*) self)->eds_backend;
#line 62 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp34_ = _g_object_ref0 (c2);
#line 62 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	eds_test_backend_add_contact (_tmp33_, _tmp34_);
#line 64 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_individual_retrieval_tests_test_singleton_individuals_async (self, NULL, NULL);
#line 66 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp35_ = self->priv->_main_loop;
#line 66 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_tmp35_, 5);
#line 68 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp36_ = self->priv->_found_individuals;
#line 68 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp37_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp36_);
#line 68 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp38_ = _tmp37_;
#line 68 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_vala_assert (_tmp38_ == 2, "this._found_individuals.size == 2");
#line 38 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	__vala_GValue_free0 (v);
#line 38 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_g_object_unref0 (c2);
#line 38 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_g_object_unref0 (c1);
#line 377 "individual-retrieval.c"
}


static void _individual_retrieval_tests_test_singleton_individuals_async_data_free (gpointer _data) {
	IndividualRetrievalTestsTestSingletonIndividualsAsyncData* _data_;
	_data_ = _data;
#line 25 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_g_object_unref0 (_data_->self);
#line 25 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	g_slice_free (IndividualRetrievalTestsTestSingletonIndividualsAsyncData, _data_);
#line 388 "individual-retrieval.c"
}


static void _individual_retrieval_tests_test_singleton_individuals_async (IndividualRetrievalTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	IndividualRetrievalTestsTestSingletonIndividualsAsyncData* _data_;
	IndividualRetrievalTests* _tmp0_ = NULL;
#line 25 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_data_ = g_slice_new0 (IndividualRetrievalTestsTestSingletonIndividualsAsyncData);
#line 25 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _individual_retrieval_tests_test_singleton_individuals_async);
#line 25 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _individual_retrieval_tests_test_singleton_individuals_async_data_free);
#line 25 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 25 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_data_->self = _tmp0_;
#line 25 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_individual_retrieval_tests_test_singleton_individuals_async_co (_data_);
#line 407 "individual-retrieval.c"
}


static void _individual_retrieval_tests_test_singleton_individuals_finish (IndividualRetrievalTests* self, GAsyncResult* _res_) {
	IndividualRetrievalTestsTestSingletonIndividualsAsyncData* _data_;
#line 25 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 415 "individual-retrieval.c"
}


static void _individual_retrieval_tests_test_singleton_individuals_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	IndividualRetrievalTestsTestSingletonIndividualsAsyncData* _data_;
#line 74 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_data_ = _user_data_;
#line 74 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_data_->_source_object_ = source_object;
#line 74 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_data_->_res_ = _res_;
#line 74 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_individual_retrieval_tests_test_singleton_individuals_async_co (_data_);
#line 429 "individual-retrieval.c"
}


static void __individual_retrieval_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 79 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_individual_retrieval_tests_individuals_changed_cb ((IndividualRetrievalTests*) self, changes);
#line 436 "individual-retrieval.c"
}


static gboolean _individual_retrieval_tests_test_singleton_individuals_async_co (IndividualRetrievalTestsTestSingletonIndividualsAsyncData* _data_) {
#line 71 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	switch (_data_->_state_) {
#line 71 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		case 0:
#line 445 "individual-retrieval.c"
		goto _state_0;
#line 71 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		case 1:
#line 449 "individual-retrieval.c"
		goto _state_1;
#line 71 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		case 2:
#line 453 "individual-retrieval.c"
		goto _state_2;
#line 71 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		case 3:
#line 457 "individual-retrieval.c"
		goto _state_3;
		default:
#line 71 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		g_assert_not_reached ();
#line 462 "individual-retrieval.c"
	}
	_state_0:
#line 74 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_data_->_tmp0_ = NULL;
#line 74 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_data_->_tmp0_ = ((EdsTestTestCase*) _data_->self)->eds_backend;
#line 74 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_data_->_state_ = 1;
#line 74 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	eds_test_backend_commit_contacts_to_addressbook (_data_->_tmp0_, _individual_retrieval_tests_test_singleton_individuals_async_ready, _data_);
#line 74 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	return FALSE;
#line 475 "individual-retrieval.c"
	_state_1:
#line 74 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	eds_test_backend_commit_contacts_to_addressbook_finish (_data_->_tmp0_, _data_->_res_);
#line 76 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_data_->_tmp1_ = NULL;
#line 76 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_data_->_tmp1_ = folks_backend_store_dup ();
#line 76 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_data_->store = _data_->_tmp1_;
#line 77 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_data_->_state_ = 2;
#line 77 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	folks_backend_store_prepare (_data_->store, _individual_retrieval_tests_test_singleton_individuals_async_ready, _data_);
#line 77 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	return FALSE;
#line 491 "individual-retrieval.c"
	_state_2:
#line 77 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 78 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_data_->_tmp2_ = NULL;
#line 78 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_data_->_tmp2_ = folks_individual_aggregator_dup ();
#line 78 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 78 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_data_->self->priv->_aggregator = _data_->_tmp2_;
#line 79 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_data_->_tmp3_ = NULL;
#line 79 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 79 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	g_signal_connect_object (_data_->_tmp3_, "individuals-changed-detailed", (GCallback) __individual_retrieval_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 509 "individual-retrieval.c"
	{
#line 83 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		_data_->_tmp4_ = NULL;
#line 83 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		_data_->_tmp4_ = _data_->self->priv->_aggregator;
#line 83 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		_data_->_state_ = 3;
#line 83 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		folks_individual_aggregator_prepare (_data_->_tmp4_, _individual_retrieval_tests_test_singleton_individuals_async_ready, _data_);
#line 83 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		return FALSE;
#line 521 "individual-retrieval.c"
		_state_3:
#line 83 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp4_, _data_->_res_, &_data_->_inner_error_);
#line 83 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		if (_data_->_inner_error_ != NULL) {
#line 527 "individual-retrieval.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 81 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		_data_->e = _data_->_inner_error_;
#line 81 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		_data_->_inner_error_ = NULL;
#line 87 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		_data_->_tmp5_ = NULL;
#line 87 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		_data_->_tmp5_ = _data_->e;
#line 87 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		_data_->_tmp6_ = NULL;
#line 87 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		_data_->_tmp6_ = _data_->_tmp5_->message;
#line 87 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		g_warning ("individual-retrieval.vala:87: Error when calling prepare: %s\n", _data_->_tmp6_);
#line 81 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		_g_error_free0 (_data_->e);
#line 550 "individual-retrieval.c"
	}
	__finally0:
#line 81 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	if (_data_->_inner_error_ != NULL) {
#line 81 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		_g_object_unref0 (_data_->store);
#line 81 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 81 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		g_clear_error (&_data_->_inner_error_);
#line 81 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		return FALSE;
#line 563 "individual-retrieval.c"
	}
#line 71 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_g_object_unref0 (_data_->store);
#line 71 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	if (_data_->_state_ == 0) {
#line 71 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 571 "individual-retrieval.c"
	} else {
#line 71 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 575 "individual-retrieval.c"
	}
#line 71 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	g_object_unref (_data_->_async_result);
#line 71 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	return FALSE;
#line 581 "individual-retrieval.c"
}


static void _individual_retrieval_tests_individuals_changed_cb (IndividualRetrievalTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeHashSet* _tmp20_ = NULL;
	gint _tmp21_ = 0;
	gint _tmp22_ = 0;
	GeeSet* _tmp24_ = NULL;
	gint _tmp25_ = 0;
	gint _tmp26_ = 0;
#line 91 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	g_return_if_fail (self != NULL);
#line 91 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	g_return_if_fail (changes != NULL);
#line 94 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp0_ = changes;
#line 94 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 94 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	added = _tmp1_;
#line 95 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp2_ = changes;
#line 95 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 95 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	removed = _tmp3_;
#line 614 "individual-retrieval.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 97 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		_tmp4_ = added;
#line 97 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 97 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		_i_it = _tmp5_;
#line 97 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		while (TRUE) {
#line 627 "individual-retrieval.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
			GeeSet* _tmp12_ = NULL;
			GeeSet* _tmp13_ = NULL;
			gint _tmp14_ = 0;
			gint _tmp15_ = 0;
			GeeHashSet* _tmp16_ = NULL;
			FolksIndividual* _tmp17_ = NULL;
			const gchar* _tmp18_ = NULL;
			const gchar* _tmp19_ = NULL;
#line 97 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			_tmp6_ = _i_it;
#line 97 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 97 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			if (!_tmp7_) {
#line 97 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
				break;
#line 651 "individual-retrieval.c"
			}
#line 97 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			_tmp8_ = _i_it;
#line 97 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 97 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			i = (FolksIndividual*) _tmp9_;
#line 99 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			_tmp10_ = i;
#line 99 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 101 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			_tmp11_ = i;
#line 101 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			_tmp12_ = folks_individual_get_personas (_tmp11_);
#line 101 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			_tmp13_ = _tmp12_;
#line 101 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			_tmp14_ = gee_collection_get_size ((GeeCollection*) _tmp13_);
#line 101 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			_tmp15_ = _tmp14_;
#line 101 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			_vala_assert (_tmp15_ == 1, "i.personas.size == 1");
#line 102 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			_tmp16_ = self->priv->_found_individuals;
#line 102 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			_tmp17_ = i;
#line 102 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			_tmp18_ = folks_individual_get_id (_tmp17_);
#line 102 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			_tmp19_ = _tmp18_;
#line 102 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp16_, _tmp19_);
#line 97 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			_g_object_unref0 (i);
#line 687 "individual-retrieval.c"
		}
#line 97 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		_g_object_unref0 (_i_it);
#line 691 "individual-retrieval.c"
	}
#line 105 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp20_ = self->priv->_found_individuals;
#line 105 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp21_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp20_);
#line 105 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp22_ = _tmp21_;
#line 105 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	if (_tmp22_ == 2) {
#line 701 "individual-retrieval.c"
		GMainLoop* _tmp23_ = NULL;
#line 107 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		_tmp23_ = self->priv->_main_loop;
#line 107 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		g_main_loop_quit (_tmp23_);
#line 707 "individual-retrieval.c"
	}
#line 110 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp24_ = removed;
#line 110 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp25_ = gee_collection_get_size ((GeeCollection*) _tmp24_);
#line 110 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp26_ = _tmp25_;
#line 110 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_vala_assert (_tmp26_ == 1, "removed.size == 1");
#line 717 "individual-retrieval.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp27_ = NULL;
		GeeIterator* _tmp28_ = NULL;
#line 112 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		_tmp27_ = removed;
#line 112 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		_tmp28_ = gee_iterable_iterator ((GeeIterable*) _tmp27_);
#line 112 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		_i_it = _tmp28_;
#line 112 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		while (TRUE) {
#line 730 "individual-retrieval.c"
			GeeIterator* _tmp29_ = NULL;
			gboolean _tmp30_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp31_ = NULL;
			gpointer _tmp32_ = NULL;
			FolksIndividual* _tmp33_ = NULL;
#line 112 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			_tmp29_ = _i_it;
#line 112 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			_tmp30_ = gee_iterator_next (_tmp29_);
#line 112 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			if (!_tmp30_) {
#line 112 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
				break;
#line 745 "individual-retrieval.c"
			}
#line 112 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			_tmp31_ = _i_it;
#line 112 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			_tmp32_ = gee_iterator_get (_tmp31_);
#line 112 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			i = (FolksIndividual*) _tmp32_;
#line 114 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			_tmp33_ = i;
#line 114 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			_vala_assert (_tmp33_ == NULL, "i == null");
#line 112 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
			_g_object_unref0 (i);
#line 759 "individual-retrieval.c"
		}
#line 112 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
		_g_object_unref0 (_i_it);
#line 763 "individual-retrieval.c"
	}
#line 91 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_g_object_unref0 (removed);
#line 91 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_g_object_unref0 (added);
#line 769 "individual-retrieval.c"
}


static void individual_retrieval_tests_class_init (IndividualRetrievalTestsClass * klass) {
#line 25 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	individual_retrieval_tests_parent_class = g_type_class_peek_parent (klass);
#line 25 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	g_type_class_add_private (klass, sizeof (IndividualRetrievalTestsPrivate));
#line 25 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	G_OBJECT_CLASS (klass)->finalize = individual_retrieval_tests_finalize;
#line 780 "individual-retrieval.c"
}


static void individual_retrieval_tests_instance_init (IndividualRetrievalTests * self) {
#line 25 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	self->priv = INDIVIDUAL_RETRIEVAL_TESTS_GET_PRIVATE (self);
#line 787 "individual-retrieval.c"
}


static void individual_retrieval_tests_finalize (GObject* obj) {
	IndividualRetrievalTests * self;
#line 25 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_INDIVIDUAL_RETRIEVAL_TESTS, IndividualRetrievalTests);
#line 27 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 28 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 29 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_g_object_unref0 (self->priv->_found_individuals);
#line 25 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	G_OBJECT_CLASS (individual_retrieval_tests_parent_class)->finalize (obj);
#line 803 "individual-retrieval.c"
}


GType individual_retrieval_tests_get_type (void) {
	static volatile gsize individual_retrieval_tests_type_id__volatile = 0;
	if (g_once_init_enter (&individual_retrieval_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (IndividualRetrievalTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) individual_retrieval_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (IndividualRetrievalTests), 0, (GInstanceInitFunc) individual_retrieval_tests_instance_init, NULL };
		GType individual_retrieval_tests_type_id;
		individual_retrieval_tests_type_id = g_type_register_static (EDS_TEST_TYPE_TEST_CASE, "IndividualRetrievalTests", &g_define_type_info, 0);
		g_once_init_leave (&individual_retrieval_tests_type_id__volatile, individual_retrieval_tests_type_id);
	}
	return individual_retrieval_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	IndividualRetrievalTests* tests = NULL;
	IndividualRetrievalTests* _tmp0_ = NULL;
#line 121 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	g_test_init (&args_length1, &args, NULL);
#line 123 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_tmp0_ = individual_retrieval_tests_new ();
#line 123 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	tests = _tmp0_;
#line 124 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 125 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	g_test_run ();
#line 126 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 128 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	result = 0;
#line 128 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	_g_object_unref0 (tests);
#line 128 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	return result;
#line 841 "individual-retrieval.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 119 "/opt/gnome3/source/folks/tests/eds/individual-retrieval.vala"
	return _vala_main (argv, argc);
#line 851 "individual-retrieval.c"
}



